
source("D:/R_Package_Estimation/Package_02122016/MDCEV_Outside_Estimating/mdcev_outside.r");

Data <<- read.table("D:/R_Package_Estimation/Package_02122016/MDCEV_Outside_Estimating/testout.csv", header=T, sep=",") 

numout <- 1;      # Number of outside goods (i.e., always consumed goods)
config <- 1;      # Utility specification configuration, possible values: 1,4,5,6,7
alp0to1 <- 1;     # 1 if you want the Alpha values to be constrained between 0 and 1, 0 otherwise
                  # putting _alp0to1 = 1 is recommended practice and can provide estimation stability
price <- 0;       # 1 if there is price variation across goods, 0 otherwise
nc <<- 3;         # Number of alternatives (in the universal choice set) including outside goods
po <<- 1;         # Index number of ID column in input data
ivuno <- "uno"    # Position of UNO variable (i.e., the column of ones) in data set
ivsero <- "sero"  # Position of SERO variable (i.e., the column of zeros) in data set
wtind <<- "uno"   # Position of WEIGHT variable (i.e., the column of weights) in data set

maxlikmethod1 <- "BHHH"; # Method of maximum likelihood for initial estimation ("BHHH" or "BFGS") 
maxlikmethod2 <- "BFGS"; # Method of maximum likelihood for final estimation ("BHHH" or "BFGS") 

# Position of the DEPENDENT variables (i.e., the consumption quantities for each alternative - NOT consumption expenditures for each alternative).
# Number of labels = number of alternatives.
def <- c("consume1","consume2","consume3");



# Positions of PRICE variables.
# Provide labels of price variables (one label in each double-quote). Number of labels = number of alternatives.
# First good (i.e., outside good, or the first of the outside goods if there are several) should be specified as a numeraire good with price one (UNO)
# Provide all UNO variables if there is no price variation 
fp <- c(ivuno, ivuno, ivuno);

# Definition of INDEPENDENT variables.
# First 'numout' goods are those that are always consumed (i.e., the outside goods), and the first good is numeraire.
# In the following specification, ivmt[[1]], ivmt[[2]], ivmt[[3]] contain independent variable specifications (on right hand side) 
# for baseline utility (PSI) for alternatives 1, 2, and 3;
# Add a row for ivmt[[4]] below if there is a 4th alternative, another addiitonal row for ivmt[[5]] if there is a 5th alternative, ... number of rows = number of alternatives); 
# Number of columns = Number of variables including alternative specific constants; consider first alternative as base  
ivmt <- list();
ivmt[[1]] <- c("");
ivmt[[2]] <- c("uno", "hhsize");
ivmt[[3]] <- c("uno", "hhsize");


# In the following specification, ivdts[[1]], ivdts[[2]], ivdts[[3]] contain input data specifications (on right hand side) 
# for satiation parameters (alphas) for alternatives 1, 2, and 3;
# Add a row below for ivdts[[4]] if there is a 4th alternative, another additional row for ivdts[[5]] if there is a 5th alternative,.... (number of rows = number of alternatives);
# Number of columns = Number of alternatives; Note that you can also add individual-specific variables below, so that satiation varies across individuals; 
# However, you will then have to translate outputs to compute actual alpha parameters; 
# This code is written to provide you with the alpha parameters directly for the case when there is no variation in alpha across individuals 
ivdts <- list();
ivdts[[1]] <- c("uno");
ivdts[[2]] <- c("uno");
ivdts[[3]] <- c("uno");


# In the following specification, ivgts[[1]], ivgts[[2]], ivgts[[3]] contain input data specifications (on the right hand side) for translation parameters (gammas) 
# for alternatives 1, 2, and 3;
# Add a row for ivgts[[4]] if there is a 4th alternative, another additional row for ivdts[[5]] if there is a 5th alternative,.... (number of rows = number of alternatives);
# Number of columns = Number of alternatives; Note that you can also add individual-specific variables below, so that gamma varies across individuals; 
# However, you will then have to translate outputs to compute actual gamma parameters; 
# This code is written to provide you with the gamma parameters directly for the case when there is no variation in gamma across individuals; 
# Since gamma=0 for the outside goods, the first numout columns of the ivg vectors will be sero */
ivgts <- list();
ivgts[[1]] <- c("sero");
ivgts[[2]] <- c("uno");
ivgts[[3]] <- c("uno");



# Add variable names for translation and satiation variables
# The number of names for both translation and satiation should be equal to the number of alternatives
alpha_names <- c("D01","D02","D03"); 
gamma_names <- c("G01","G02","G03"); 

########################################################################################################
#  Do Not Modify Next Three Lines
########################################################################################################
arg_inds <- list(numout, config, alp0to1, price, nc, po);
arg_vars <- list(ivuno, ivsero, wtind, maxlikmethod1, maxlikmethod2);
result <- mdcev_withoutgood(Data, arg_inds, arg_vars, def, fp, ivmt, ivdts, ivgts, alpha_names, gamma_names);
########################################################################################################


summary(result);   # Show results from the MDCEV model with no outside good

